@@ -3,12 +3,11 @@ from mmengine.utils.dl_utils import TORCH_VERSION
 from mmengine.utils.version_utils import digit_version
 from .distributed import MMDistributedDataParallel
 from .seperate_distributed import MMSeparateDistributedDataParallel
-from .test_time_aug import BaseTTAModel
 from .utils import is_model_wrapper
 
 __all__ = [
     'MMDistributedDataParallel', 'is_model_wrapper',
-    'MMSeparateDistributedDataParallel', 'BaseTTAModel'
+    'MMSeparateDistributedDataParallel'
 ]
 
 if digit_version(TORCH_VERSION) >= digit_version('1.11.0'):
